/*
 * $Id: h2ps.c,v 1.20 1998/09/09 03:39:35 yjlee Exp $
 * h2ps.c - hangul-to-PostScript converter.
 * Lee yongjae, yjlee@cglab.snu.ac.kr, 1998.07.31.
 *
 * Copyright (c) 1998 by Lee yongjae, in dept. of Computer Science
 * in Seoul National University, Korea.
 *
 * Permission to use, copy, modify, and distribute this software and its
 * documentation for any purpose and without fee is hereby granted, 
 * provided that the above copyright notice appear in all copies and
 * that both that copyright notice and this permission notice appear in
 * supporting documentation, and that the name of the copyright holder
 * not be used in advertising or publicity pertaining to distribution
 * of the software without specific, written prior permission.
 *
 * This software is provided "as is" without express or implied warranty.
 */

#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include <sys/types.h>
#include <time.h>
#include <unistd.h>

#include "ncode.h"
#include "npsr2.h"

extern char *optarg;
extern int optind, opterr, optopt;

#define LINE_BUF_SIZE     1000
#define BOX_PER_PAGE_MAX  10

FILE *in = 0, *out = 0;
char *in_file;

/* scales in point */
double font_size = 9;
double eng_mag = .9;
double line_mag = 1.12;
double page_width = 595;   /* A4 width */
double page_height = 842;  /* A4 height */
double left_margin = 40;
double right_margin = 40;
double top_margin = 40;
double bottom_margin = 40;
double box_gap = 20;
double decoration_gap = 8;
int box_per_page = 2;

int is_print_line_number = 0;
int is_landscape = 1;
int is_heading = 1;
int is_decoration = 1;
int is_verbose = 1;

double heading_font_size = 9;
double heading_height = 25;
double heading_x, heading_y;

double decoration_font_size = 10;
double decoration_heading_height = 16;

double line_height;
unsigned char line_buf[LINE_BUF_SIZE];
int line_index, line_num;
double line_width, line_width_max;
double line_number_width;

int box_line_num, box_line_num_max;
int box_num;  /* 0 <= box_num < box_per_page */
int box_width, box_height;
double box_pos[BOX_PER_PAGE_MAX][2];  /* left up coordinate of each box */

char date_str[100];
int page_num = 0;
int in_page_num = 0;
int box_page_num = 0;

int is_in_box = 0;
int is_in_page = 0;

double get_char_width(/* int c */);  /* defined in "font_metric.c" */

int
ks2n_fgetc(fp)
     FILE *fp;
{
  static unsigned char buf[4] = {0};
  unsigned char *p;
  int c, i;
  unsigned short k;

  if (buf[0] == 0) {
    while ((c = fgetc(fp)) != EOF) {
      if (c >= 128) {
	k = (c << 8) | fgetc(fp);
	p = ks_to_n(k, buf);
	
	if (p > buf) {
	  *p = 0;
	  break;
	}
	
	/* unconvertable character; continue */
      }
      else
	return c;
    }
    if (c == EOF)
      return c;
  }

  c = buf[0];
  for (i = 0; buf[i]; i++)  /* buffer shift left */
    buf[i] = buf[i + 1];

  return c;
}

int
filter_fgetc(fp)
     FILE *fp;
{
#define TAB_SIZE  8
  static FILE *last_fp = 0;
  static int buf[TAB_SIZE + 2];
  static int i = 0;  /* number of characters in buffer */
  int c, j;

  if (fp != last_fp) {  /* new file pointer; clear buf */
    buf[0] = 0;
    last_fp = fp;
  }
  if (!fp)
    return 0;
  
  while (i <= 1) {
    buf[i] = ks2n_fgetc(fp);
    i++;

    if (buf[i - 1] == '\b' && i >= 2) {
      i -= 2;  /* if new char is \b then ignore last two */
    }
    else if (buf[i - 1] == '\t') {
      for (j = 0; j < TAB_SIZE; j++)
	buf[i + j - 1] = ' ';
      i += TAB_SIZE - 1;
    }
  }
  
  c = buf[0];
  for (j = 0; j < i - 1; j++)  /* buffer shift left */
    buf[j] = buf[j + 1];
  i--;

  return c;
}

void
init_parameter()
{
  time_t tm;
  int i;
  double w, h, l_m, r_m, t_m, b_m;
  double a_h;

  tm = time(0);
  strcpy(date_str, ctime(&tm));
  date_str[strlen(date_str) - 1] = 0;  /* chop the last character, '\n' */

  if (is_landscape) {
    w = page_height;
    h = page_width;
    l_m = bottom_margin;
    r_m = top_margin;
    t_m = left_margin;
    b_m = right_margin;
  }
  else {
    w = page_width;
    h = page_height;
    l_m = left_margin;
    r_m = right_margin;
    t_m = top_margin;
    b_m = bottom_margin;
  }

  if (is_decoration) {
    l_m += decoration_gap;
    r_m += decoration_gap;
    t_m += decoration_gap;
    b_m += decoration_gap;
    box_gap += decoration_gap * 2;
  }

  if (is_decoration) {
    a_h = decoration_heading_height;
  }
  else if (is_heading) {
    a_h = heading_height;
    heading_x = w - r_m;
    heading_y = h - t_m;
  }
  else
    a_h = 0;

  line_height = font_size * line_mag;

  box_width = (w - l_m - r_m - box_gap * (box_per_page - 1)) / box_per_page;
  box_height = h - t_m - a_h - b_m;
  box_line_num_max = box_height / line_height;

  for (i = 0; i < box_per_page; i++) {
    box_pos[i][0] = l_m + (box_width + box_gap) * i;
    box_pos[i][1] = b_m + box_height;
  }

  if (is_print_line_number)
    line_number_width = get_char_width('0') * 4 + get_char_width(' ') * 4;
  else
    line_number_width = 0;

  line_width_max = box_width - line_number_width;
}

void
print_prolog()
{
  fputs("%!PS-Adobe-3.0\n", out);
  fputs("%%Creator: h2ps\n", out);
  fprintf(out, "%%%%CreationDate: %s\n", date_str);
  fputs("%%Pages: (atend)\n", out);
  fputs("%%EndComments\n", out);
  
  npsr_insert_resource(out, NPSR_FONT, "n3f-5");
  npsr_insert_resource(out, NPSR_FILE, "nfont.ps");

  fprintf(out, "/font_size %g def\n", font_size);
  fprintf(out, "/heading_font_size %g def\n", heading_font_size);
  fprintf(out, "/deco_font_size %g def\n", decoration_font_size);
  fprintf(out, "/eng_mag %g def\n", eng_mag);
  fprintf(out, "/line_height %g def\n", line_height);
  fprintf(out, "/line_number_width %g def\n", line_number_width);
  fprintf(out, "/date (%s) def\n", date_str);
  fprintf(out, "/landscape %s def\n", (is_landscape)? "true" : "false");
  fprintf(out, "/page_width %g def\n", page_width);
  fprintf(out, "/page_height %g def\n", page_height);
  fprintf(out, "/deco_h %g def\n", decoration_heading_height);

  fputs("\
/bd { bind def } bind def\n\
/body_font {\n\
  /Times-Roman findfont font_size eng_mag mul scalefont setfont\n\
  /n3f-5 findfont font_size scalefont nsetfont\n\
} bd\n\
/heading_font {\n\
  /Times-Roman findfont heading_font_size eng_mag mul scalefont setfont\n\
  /n3f-5 findfont heading_font_size scalefont nsetfont\n\
} bd\n\
/deco_font {\n\
  /Helvetica findfont deco_font_size eng_mag mul scalefont setfont\n\
  /n3f-5 findfont deco_font_size scalefont nsetfont\n\
} bd\n\
/deco_file_font {\n\
  /Helvetica-Bold findfont deco_font_size 1 add eng_mag mul scalefont setfont\n\
  /n3f-5 findfont deco_font_size 1 add scalefont nsetfont\n\
} bd\n\
/ln {  %  <line number str> ln -\n\
  nshow\n\
  line_number_width 0 moveto\n\
} bd\n\
/n {  %  <string> n -\n\
  nshow 0 line_height neg translate 0 0 moveto\n\
} bd\n\
/begin_box {  %  <left up x> <left up y> begin_box -\n\
  gsave translate\n\
  0 line_height .75 mul neg translate 0 0 moveto\n\
  body_font\n\
} bd\n\
/end_box {\n\
  grestore\n\
} bd\n\
/begin_page {\n\
  gsave\n\
  landscape { page_width 0 translate 90 rotate } if\n\
} bd\n\
/end_page {\n\
  grestore\n\
} bd\n\
/page_number {  %  <x> <y> <page number> page_numer -\n\
  pop pop pop % do nothing\n\
} bd\n\
/heading {  %  <right top x> <right top y> <head string> heading -\n\
  gsave 3 1 roll moveto\n\
  heading_font\n\
  dup nstringwidth pop neg heading_font_size .75 mul neg rmoveto nshow\n\
  grestore\n\
} bd\n\
/decoration {  % <lux> <luy> <w> <h> <date str> <file name str> <page str> decoration -\n\
  gsave\n\
  /_page_ exch def /_file_ exch def /_date_ exch def\n\
  /_h_ exch def /_w_ exch def translate newpath\n\
  0 0 moveto _w_ 0 rlineto 0 deco_h rlineto _w_ neg 0 rlineto\n\
  0 deco_h neg rlineto closepath\n\
  gsave .9 setgray fill grestore .5 setlinewidth stroke\n\
  0 0 moveto 0 _h_ neg rlineto _w_ 0 rlineto 0 _h_ rlineto stroke\n\
  /_g_ deco_h deco_font_size sub .5 mul def /_wg_ _g_ 1.2 mul def\n\
  /_w_ _w_ _wg_ sub _wg_ sub def\n\
  _wg_ _g_ deco_font_size .2 mul add translate\n\
  deco_font 0 0 moveto _date_ nshow\n\
  _w_ _page_ nstringwidth pop sub 0 moveto _page_ nshow\n\
  deco_file_font _w_ _file_ nstringwidth pop sub .5 mul 0 moveto _file_ nshow\n\
  grestore\n\
} bd\n\
",
   out);
}

void
end_page()
{
  fprintf(out, "end_page\n");
  fprintf(out, "showpage\n");

  is_in_page = 0;
}

void
begin_page()
{
  char buf[256], heading[512], *p;

  if (is_in_page)
    end_page();

  page_num++;
  in_page_num++;

  fprintf(out, "%%%%Page: %d %d\n", page_num, page_num);
  fprintf(out, "begin_page\n");

  if (is_heading) {
    sprintf(buf, "%s   %s   page %d", date_str, in_file, in_page_num);
    kston(buf, heading);
    fprintf(out, "%g %g <", heading_x, heading_y);
    for (p = heading; *p; p++)
      fprintf(out, "%02x", (int)*p);
    fprintf(out, "> heading\n");
  }

  box_num = 0;
  is_in_page = 1;
}

void
end_box()
{
  fprintf(out, "end_box\n");
  
  is_in_box = 0;
  box_num = (box_num + 1) % box_per_page;
}

void
begin_box()
{
  char heading[512], *p;

  if (is_in_box)
    end_box();
  
  if (box_num % box_per_page == 0)
    begin_page();
  
  box_page_num++;
  
  if (is_decoration) {
    fprintf(out, "%g %g %g %g (%s) <\n",
	    box_pos[box_num][0] - decoration_gap,
	    box_pos[box_num][1] + decoration_gap,
	    box_width + decoration_gap * 2,
	    box_height + decoration_gap * 2,
	    date_str);
    
    kston(in_file, heading);
    for (p = heading; *p; p++)
      fprintf(out, "%02x", (int)*p);
    fprintf(out, "> (Page %d) decoration\n", box_page_num);
  }
  
  fprintf(out, "%g %g begin_box\n", box_pos[box_num][0], box_pos[box_num][1]);

  is_in_box = 1;
  box_line_num = 0;
}

void
flush_page()
{
  if (is_in_page)
    end_page();
}

void
flush_box()
{
  if (is_in_box)
    end_box();
}

void
flush_line()
{
  static int last_line_num = -1;
  unsigned char *p;
  int out_size, i;
  double width;

  if (line_index == 0)
    return;

  if (is_in_box && box_line_num >= box_line_num_max)
    end_box();

  if (!is_in_box)
    begin_box();

  box_line_num++;
  line_buf[line_index] = 0;

  out_size = line_index;
  while (line_width > line_width_max) {  /* dumy loop */
    if ((p = strrchr(line_buf, ' ')))  /* find last space */
      if (strspn(line_buf, " ") < p - line_buf) {
	out_size = p - line_buf;
	break;
      }
    /* space cannot be found or the fisrt segment is only space span */
    for (i = line_index - 2; i >= 1; i--)
      if (!NCODE_ONE_HCHAR(line_buf[i - 1], line_buf[i]))
	break;
    out_size = i;
    break;
  }

  /* print line */
  if (is_print_line_number) {
    if (last_line_num != line_num) {
      fprintf(out, "(%d) ln ", line_num);
      last_line_num = line_num;
    }
    else
      fprintf(out, "() ln ");
  }

  fprintf(out, "<");
  for (i = 0; i < out_size; i++) {
    if ((int)line_buf[i] >= 0x20) {
      fprintf(out, "%02x", (int)line_buf[i]);
      if ((i + 1) % 35 == 0)  /* per each 35 characters */
	fprintf(out, "\n");
    }
  }
  fprintf(out, "> n\n");

  memmove(line_buf, &line_buf[out_size], line_index - out_size);
  line_index -= out_size;
  line_width = 0;
  for (i = 0; i < line_index; i++)
    line_width += get_char_width(line_buf[i]);
}

void
insert_char_to_line(c)
     int c;
{
  if (line_index + 1 >= LINE_BUF_SIZE)
    flush_line();

  line_buf[line_index++] = c;
  line_width += get_char_width(c);

  if (line_width > line_width_max)
    flush_line();
}


void
usage()
{
  fputs(
"\
h2ps 2.06 - converts hangul text file to PostScript file\n\
usage: h2ps [ options ] [ infile [ ... ] ] ]\n\
options:\n\
    -l     : landscape (default)\n\
    -p     : portrait\n\
    -1|2|3 : 1, 2 or 3 columns (default: 2 columns)\n\
    -c n   : n columns (1 <= n <= 10)\n\
    -n     : line numbering\n\
    -f n   : font size (n is real number)\n\
    -H     : do not display heading\n\
    -q     : quiet\n\
    -L     : use Letter page size (default: A4)\n\
    -D     : do not draw decoration box and heading (default: draw decoration)\n\
    -h     : this message\n\
default format:\n\
    A4 landscape two column mode with decoration and heading.\n\
", stderr);
}

int
main(argc, argv)
     int argc;
     char *argv[];
{
  int c, errflg;
  int total_box_page_num;

  errflg = 0;
  while ((c = getopt(argc, argv, "lp123c:nf:dHLDqh")) != -1) {
    switch (c) {
    case 'l': is_landscape = 1; break;
    case 'p': is_landscape = 0; break;
    case '1': box_per_page = 1; break;
    case '2': box_per_page = 2; break;
    case '3': box_per_page = 3; break;
    case 'c': sscanf(optarg, "%d", &box_per_page); break;
    case 'n': is_print_line_number = 1; break;
    case 'f': sscanf(optarg, "%lg", &font_size); break;
    case 'H': is_heading = 0; break;
    case 'L': page_width = 612; page_height = 792; break;  /* Letter size */
    case 'D': is_decoration = 0; break;
    case 'q': is_verbose = 0; break;
    case 'h': errflg++; break;
    case '?': errflg++; break;
    }
    if (errflg) {
      usage();
      return -1;
    }
  }

  if (is_decoration)
    is_heading = 0;
 
  /* print out loop */

  out = stdout;
  in_file = (argc == optind)? "-" : argv[optind];

  init_parameter();
  print_prolog();

  page_num = 0;
  total_box_page_num = 0;

  while (in_file) {
    if (!strcmp(in_file, "-")) {
      in = stdin;
      in_file = "stdin";
    }
    else {
      if (!(in = fopen(in_file, "r")))
	perror(in_file);
    }

    filter_fgetc(0);

    if (in) {
      line_index = 0;
      line_width = 0;
      line_num = 1;
      box_line_num = 0;
      box_page_num = 0;
      box_num = 0;
      in_page_num = 0;
      
      while ((c = filter_fgetc(in)) != EOF) {
	insert_char_to_line(c);

	if (c == '\n' || c == '\f') {
	  flush_line();
	  if (c == '\f')
	    flush_box();
	  line_num++;
	}
      }
      
      flush_line();
      flush_box();
      flush_page();
      
      if (is_verbose)
	fprintf(stderr, "[%s: %d pages on %d sheets]\n", in_file, box_page_num, in_page_num);

      fclose(in);
    }

    total_box_page_num += box_page_num;
    
    optind++;
    in_file = (optind < argc)? argv[optind] : 0;
  }

  if (is_verbose)
    fprintf(stderr, "[Total: %d pages on %d sheets]\n",total_box_page_num, page_num);
   
}
